@@ -120,7 +120,7 @@ class ValidatedParameter:
                     if hasattr(validator, "_error_message"):
                         errors.append(validator.message(value))
                     else:  # calling the validator statically
-                        errors.append(validator.ERROR_MESSAGE)
+                        errors.append(validator.ERROR_MESSAGE.format(value=value))
                     if not group_errors:
                         return errors
 
@@ -130,7 +130,7 @@ class ValidatedParameter:
 class Parameter(ValidatedParameter, BaseParameter):
     """Class used to encapsulate the extract methods parameter data."""
 
-    def __init__(self, path="", func_param_name=None, validators=None, var_name=None, default=None):  # noqa: pylint - too-many-arguments
+    def __init__(self, path="", func_param_name=None, validators=None, var_name=None, default=None, transform=None):  # noqa: pylint - too-many-arguments
         """
         Sets the private variables of the Parameter object.
 
@@ -154,9 +154,11 @@ class Parameter(ValidatedParameter, BaseParameter):
                 value is the last element of the path (e.g. "c" in the case above)
             default (any): Optional, a default value if the value is missing and not mandatory.
                 The default value is None
+            transform (function): Optional, a function to apply to the extracted value before checking validation rules.
         """
         self._path = path
         self._default = default
+        self._transform = transform
         ValidatedParameter.__init__(self, func_param_name, validators)
         BaseParameter.__init__(self, var_name)
 
@@ -179,15 +181,17 @@ class Parameter(ValidatedParameter, BaseParameter):
         """
         for path_key in filter(lambda item: item != "", self._path.split(PATH_DIVIDER)):
             real_key, annotation = Parameter.get_annotations_from_key(path_key)
-            if real_key in dict_value:
+            if dict_value and real_key in dict_value:
                 dict_value = decode(annotation, dict_value[real_key])
             else:
                 dict_value = self._default
-                break
 
         if not self._name:
             self._name = real_key
 
+        if dict_value and self._transform:
+            dict_value = self._transform(dict_value)
+
         return dict_value
 
     def validate_path(self, value, group_errors=False):
